; ===========================================================================
; Amiga code/stuff testbed
; ===========================================================================
COMPATIBILITY	= 1		; 0: 68k, Kick1.3, PAL / 1: All CPUs, Kickstarts and display modes
RMBPAUSE		= 0		; Set to 1 to enable pause on right mouse button
FPUINT			= 0		; Set to 1 if you use FPU code in your interrupt
COPPER			= 1
BLITTER			= 0
SPRITE			= 0
TOPAZ			= 1		; Set to 1 to get address of topaz font data in TopazCharData
SECTIONHACK		= 0		; Set to 1 when writing the object file to enable section hack
; ===========================================================================

_LVORawDoFmt  equ  -522

	include	startup.asm

	section	code,code

; ===========================================================================
; INIT
; ===========================================================================

_Precalc:
	cmp.b	#'x',(a0)+
	bne		.noarg
	moveq	#0,d0
	move.b	(a0),d0
	sub.b	#'0',d0
	add.w	d0,d0
	add.w	d0,heartstartrow
.noarg

	bsr		heartbeat_init

	rts

info:
	dc.b 'wait = $yy%02x,$fffe',0
	even
args:
	dc.w	0,0,0,0,0,0
debugbuffer:
	ds.b	128

; ===========================================================================
; CLEANUP
; ===========================================================================

_Exit:
	moveq	#0,d0
	rts

; ===========================================================================
; MAIN
; ===========================================================================

_Main:
	move.l	#herzcopper,$dff080
.mainloop

	bra		.mainloop

; ===========================================================================
; INTERRUPT
; ===========================================================================
tmprst:		dc.l 0

_Interrupt:
	btst	#10,$016(a3)
	beq.b	.skip
	bsr		heartbeat_step

; debuginfo(a0:string, a1:args, a4:screen, d3.w:line_offset)
	lea		info,a0
	lea		args,a1
	move.w	heartstartrow,(a1)
	and.w	#$ff,(a1)
	lea		herzspace+40*4*60+14,a4
	move.w	#40*4,d3
	bsr		debuginfo

.skip
	rts

; ===========================================================================
; EFFECT TEST
; ===========================================================================

HERZ_ROWS = 80+40		; heart height + buffer

heartbeat_init:
	; Set BPL pointers in copperlist
	lea		herzbpls,a1
	move.l	#herzspace,d0
	moveq	#4-1,d1
.setbpl
	move.w	d0,6(a1)
	swap	d0
	move.w	d0,2(a1)
	swap	d0
	add.w	#40,d0
	add.w	#8,a1
	dbf		d1,.setbpl

	; Copy sprite colors into copperlist
	lea		herzcols,a0
	lea		herzcoppercols,a1
	move.w	#$0180,d0
	moveq	#8-1,d1
.copyherzcol
	move.w	d0,(a1)+
	move.w	(a0)+,(a1)+
	addq	#2,d0
	dbf		d1,.copyherzcol

	; processor-blit the herz into the screen space
	lea		herzspace+40*4,a0
	lea		herz,a1
	move.w	#80-1,d0
.herzrows
	; herz is 96 px wide == 3 longwords
	moveq	#3-1,d1
.herzrow
	move.l	(a1)+,(a0)+
	move.l	(a1)+,(a0)+
	move.l	(a1)+,(a0)+
	add.w	#40-12,a0
	dbf		d1,.herzrow
	add.w	#40,a0
	dbf		d0,.herzrows
	rts


heartstartrow:		dc.w	$6021
heartanimphase:		dc.w	0
heartbeatindexes:	dc.w	8,7,6,5,4,3,2,1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,14,13,12,11,10,9
heartfade:			dc.w	32+6*4

heartbeat_step:
	; select heart beat zoom index
	move.w	VBlank+2,d0
	and.w	#$1f,d0
	cmp.b	#8,d0
	beq		.beatit
	bra		.nobeat
.beatit
	move.w	#2*30,heartanimphase
.nobeat
	move.w	heartanimphase,d0
	beq		.firstheartbeatindex
	subq	#2,d0
	move.w	d0,heartanimphase
.firstheartbeatindex
	lea		heartbeatindexes,a0
	move.w	(a0,d0.w),d0

	; Write copperlist
	lea		herzshifts,a0
	move.w	d0,d3
	mulu	#2*14,d0
	add.w	d0,a0
	lea		herzvshifts,a2
	mulu	#2*HERZ_ROWS,d3
	add.w	d3,a2

	lea		herzcoppershifts,a1
	move.w	heartstartrow,d0
	move.w	#HERZ_ROWS-1,d1
.shiftr
	; each line:
	;   <line>,$fffe
	;   $01fe,0000,$01fe,0000    <-- 2 NOPs for vert shift using modulos
	;   $0102,<sh>,$0102,<sh>... <-- 14 shifts
	move.w	d0,(a1)+
	move.w	#$fffe,(a1)+
	move.w	#$0108,(a1)+
	move.w	(a2),(a1)+
	move.w	#$010a,(a1)+
	move.w	(a2)+,(a1)+

	moveq	#14-1,d2
.cols
	move.w	#$0102,(a1)+
	move.w	(a0)+,(a1)+
	addq	#4,a1
	dbf		d2,.cols

	sub.l	#14*2,a0			; back to start of shifts
	add.w	#$0100,d0			; next line
	dbf		d1,.shiftr
	rts

; ---------------------------------------------------------------------------
; Print debug string on screen.
;
; debuginfo(a0:string, a1:args, a4:screen, d3.w:line_offset)
;
debuginfo:
	lea		debugput,a2
	lea		debugbuffer,a3
	move.l	4.w,a6
	jsr		_LVORawDoFmt(a6)	; RawDoFmt(a0:FormatString, a1:DataStream,
								;          a2:PutChProc,    a3:PutChData)
	lea		debugbuffer,a0
	move.l	a4,a1
	bra		drawtopazstring
debugput:
	move.b	d0,(a3)+
	rts

; ---------------------------------------------------------------------------
; Draws a string using Topaz.
;
; drawtopazstring(a0:string, a1:screen, d3.w:line_offset)
;
drawtopazstring:
	lea		TopazCharData(pc),a3
	move.l	(a3),a3
	move.l	a1,a4			; last line start = a4
.nextChar
	move.b	(a0)+,d0
	beq		.dungoofed

	cmp.b	#10,d0			; line break?
	bne		.nolinebreak
	move.l	a4,a1			; a1 := last line start + 8 * screen line offset
	moveq	#7,d1
.feed
	add.w	d3,a1
	dbf		d1,.feed
	move.l	a1,a4
	bra		.nextChar
.nolinebreak

	; get start of char
	sub.b	#32,d0
	move.l	a1,a2
	and.w	#$ff,d0
	move	#7,d1
.charloop
	move.b	(a3,d0.w),(a2)	; plot one byte
	add.w	d3,a2			; next line on screen
	add.w	#256-64,d0		; next line of character
	dbra	d1,.charloop

	addq	#1,a1			; step 8px to the right
	bra		.nextChar
.dungoofed:
	rts

; ===========================================================================
; CHIP DATA
; ===========================================================================

	section data,data

herz:
	incbin	"zoom.raw" ; 3bpl, 96(12 bytes) x 80, interleaved
herzcols:
	incbin	"zoom.pal"
herzcolsize = *-herzcols
	ds.w	herzcolsize*16

herzshifts:
	dc.w	$0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088, $0088 ; 00
	dc.w	$0088, $0088, $0088, $0088, $0088, $0088, $0088, $0077, $0077, $0077, $0077, $0077, $0077, $0077 ; 01
	dc.w	$0088, $0088, $0088, $0088, $0088, $0088, $0088, $0077, $0077, $0077, $0077, $0077, $0077, $0077 ; 02
	dc.w	$0099, $0099, $0088, $0088, $0088, $0088, $0088, $0077, $0077, $0077, $0077, $0077, $0066, $0066 ; 03
	dc.w	$0099, $0099, $0099, $0099, $0088, $0088, $0088, $0077, $0077, $0077, $0066, $0066, $0066, $0066 ; 04
	dc.w	$00aa, $0099, $0099, $0099, $0088, $0088, $0088, $0077, $0077, $0077, $0066, $0066, $0066, $0055 ; 05
	dc.w	$00aa, $00aa, $0099, $0099, $0099, $0088, $0088, $0077, $0077, $0066, $0066, $0066, $0055, $0055 ; 06
	dc.w	$00bb, $00aa, $00aa, $0099, $0099, $0088, $0088, $0077, $0077, $0066, $0066, $0055, $0055, $0044 ; 07
	dc.w	$00bb, $00bb, $00aa, $00aa, $0099, $0088, $0088, $0077, $0077, $0066, $0055, $0055, $0044, $0044 ; 08
	dc.w	$00cc, $00bb, $00aa, $00aa, $0099, $0088, $0088, $0077, $0077, $0066, $0055, $0055, $0044, $0033 ; 09
	dc.w	$00cc, $00bb, $00bb, $00aa, $0099, $0099, $0088, $0077, $0066, $0066, $0055, $0044, $0044, $0033 ; 10
	dc.w	$00dd, $00cc, $00bb, $00aa, $0099, $0099, $0088, $0077, $0066, $0066, $0055, $0044, $0033, $0022 ; 11
	dc.w	$00dd, $00cc, $00bb, $00bb, $00aa, $0099, $0088, $0077, $0066, $0055, $0044, $0044, $0033, $0022 ; 12
	dc.w	$00ee, $00dd, $00cc, $00bb, $00aa, $0099, $0088, $0077, $0066, $0055, $0044, $0033, $0022, $0011 ; 13
	dc.w	$00ee, $00dd, $00cc, $00bb, $00aa, $0099, $0088, $0077, $0066, $0055, $0044, $0033, $0022, $0011 ; 14
	dc.w	$00ff, $00dd, $00cc, $00bb, $00aa, $0099, $0088, $0077, $0066, $0055, $0044, $0033, $0022, $0000 ; 15

HRZM = 40*3
HRZW = 40*4

herzvshifts:
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=17, last=103
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=17, last=102
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=18, last=102
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=18, last=102
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=19, last=102
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=19, last=101
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=20, last=101
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=20, last=100
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=20, last=99
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=21, last=99
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=21, last=98
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=22, last=99
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=22, last=98
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=23, last=98
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=23, last=97
	dc.w	HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+1*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+0*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW, HRZM+-1*HRZW ; first=24, last=97

; ===========================================================================
; CHIP DATA
; ===========================================================================

	section data_c,data_c

herzcopper:
	dc.w	$008e,$2c81,$0090,$2cc1		; DIWSTRT,DIWSTOP
	dc.w	$0092,$0038,$0094,$00d0		; DDFSTRT,DDFSTOP
	dc.w	$0102,$0000,$0100,$0200
	dc.w	$0108,40*3,$010a,40*3		; BPL1MOD,BPL2MOD
herzcoppercols:
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
	dc.w	$0180,$0545,$0180,$0545,$0180,$0545,$0180,$0545
herzbpls:
	dc.w	$00e0,$0000,$00e2,$0000		; BPL1PTH/PTL
	dc.w	$00e4,$0000,$00e6,$0000		; 2
	dc.w	$00e8,$0000,$00ea,$0000		; 3
	dc.w	$00ec,$0000,$00ee,$0000		; 4
	dc.w	$5fdf,$fffe,$0100,$4200
herzcoppershifts:
	rept	HERZ_ROWS
	dc.w	$6107,$fffe,$01fe,0000,$01fe,0000
	dc.w	$0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000
	dc.w	$0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000
	dc.w	$0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000
	dc.w	$0102,$0000,$01fe,$0000, $0102,$0000,$01fe,$0000
	endr

	dc.w	$ffff,$fffe

herzspace:
	ds.b	40*HERZ_ROWS*4

	section data_c,data_c

